@@ -497,4 +497,9 @@ class ResourceSet(object):
             self._store.remove((self._subject._id, self._predicate, obj))
 
     def any(self):
-        return list(self._store.objects(self._subject._id, self._predicate))[0]
+        objs = list(self._store.objects(self._subject._id, self._predicate))
+        if len(list) > 0:
+            return objs[0]
+        else:
+            return None
+
